function K = HI_kernel_matrix(samples1,samples2, ...
			       params);
% function K = HI_kernel_matrix(samples1,samples2, ...
%				 params);
%
% function computing Haar-integration kernel matrix between the
% (column)-vectors in samples1 and samples2.
%
% If samples2 is empty, then samples2==samples1 is assumed. 
% Symmetry can then be used for
% acceleration in symmetric case if implemented for the base-kernel.
%
% required fields of params:
%    identical as used by virtual_samples_kernel_matrix

% Bernard Haasdonk 23.2.2005

[Kt,ntrans] = virtual_samples_kernel_matrix(samples1,samples2,params);

% averaging of matrix-subblocks 
[nt,mt] = size(Kt);
n = nt/ntrans;
m = mt/ntrans;
% squeeze: first direction, then second direction
K = sum(reshape(Kt,ntrans,nt*mt/ntrans),1); % now row-vector 1 x mt*n
K = reshape(K,n,mt)';
K = sum(reshape(K,ntrans,n*m),1);
K = reshape(K,m,n)'/ntrans/ntrans;
