function Dsq = IDsq_matrix(samples1,samples2,params);
% function Dsq = IDsq_matrix(samples1,samples2,params);
%
% function computing the two-sided invariant
% distance matrix between the (column)-vectors in samples1 and 
% samples2. This distance is
% defined (without regularization) as the minimum distance between 
% the sets of transformed vectors specified in params.
% In the regularized case, the distances are penalized by a 
% squared transformation parameter term.
%
% If samples2 is empty, then samples2==samples1 is assumed. 
%
% required fields of params:
%   identical as used by virtual_samples_kernel_matrix.m
%
% optional fields of params:
%   regpar      : regularization parameter used for weighted ID 
%                 0 -> unregularized ID, 
%                 Inf -> Euclidean distance (if parameter vector 0
%                 is realized in params)

% Bernard Haasdonk 7.6.2005

% compute all transformed examples and the Euclidean distances
% between them.

params.kernel_matrix_func = 'EDsq_matrix';
[Dsq,ntrans,P] = virtual_samples_kernel_matrix(samples1,samples2,params);

[nt,mt] = size(Dsq);
n = nt/ntrans;
m = mt/ntrans;

% add parameter penalty in case of regularization
if (isfield(params,'regpar') & length(params.transform_names) > 0)
  PsqrBlock = repmat(sum(P.^2,1),ntrans,1); 
  Psqr = repmat(PsqrBlock + PsqrBlock',n,m);
  Dsq = Dsq + params.regpar * Psqr;
end;

% search minimum in each subblock and extract this
% squeeze: first direction, then second direction
Dsq = reshape(Dsq,ntrans,nt*mt/ntrans); 
if size(Dsq,1)>1
  Dsq = min(Dsq); % now row-vector 1 x mt*n
end;    
Dsq = reshape(Dsq,n,mt)';
Dsq = reshape(Dsq,ntrans,n*m);
if size(Dsq,1)>1
  Dsq = min(Dsq); % now row-vector 1 x m*n
end;    
Dsq = reshape(Dsq,m,n)';

