function K = linear_DS_kernel_matrix(samples1,samples2, ...
			       params);
% function K = linear_DS_kernel_matrix(samples1,samples2, ...
%				 params);
%
% function computing linear distance substitution (DS) kernel
% matrix between the (column)-vectors in samples1 and samples2. 
%
% If samples2 is empty, then samples2==samples1 is assumed. 
%
% required fields of params:
%    b        : the bias added to the linear kernel.
%    Dsq_func : name of the squared distance function for computation of
%               distance matrix
%    origin   : vector, which is taken as origin, not necessarily in
%               samples1 or samples2
%
% K(i1,i2) is computed by  
%   -1/2( Dsq(samples1(:,i1),samples2(:,i2))
%         - Dsq(samples1(:,i1),origin )
%         - Dsq(samples2(:,i1),origin ) + b

% Bernard Haasdonk 6.10.2004

%check_required_fields(params,'b','Dsq_func','origin');

n1 = size(samples1,2);
n2 = size(samples2,2);

samples1 = [samples1, params.origin(:)];
if ~isempty(samples2)
  samples2 = [samples2, params.origin(:)];
end;

Dsq = feval(params.Dsq_func,samples1,samples2,params);

K = -1/2 * (Dsq(1:n1,1:n2) - ...
	     repmat(Dsq(end,1:n2),n1,1) - ...
	     repmat(Dsq(1:n1,end),1,n2) )   + params.b;





