function onvec = orthonormalize(vec)
% function onvec = orthonormalize(vec)
%
% Gram-Schmidt orthonormalization of vectors in columns of 
% matrix vec to onvec. Almost zero vectors are set to zero.

% Bernard Haasdonk 13.6.2002

onvec = vec;
if isempty(vec)
  return;
end;

for i = 1:size(vec,2);
  % orthogonalize vector i
  for j=1:(i-1)
    onvec(:,i)= onvec(:,i)-sum(onvec(:,i).*onvec(:,j))*onvec(:,j);
  end; 
  % normalize vector i
  n = sqrt(sum(onvec(:,i).^2));
  if (n<0.0001) 
    onvec(:,i) = 0;
  else
    onvec(:,i) = onvec(:,i)/n;
  end;
end;
