function K = poly_kernel_matrix(samples1,samples2, ...
				  params);
% function K = poly_kernel_matrix(samples1,samples2,params);
%
% function computing a polynomial kernel matrix between the
% (column)-vectors in samples1 and samples2.
%
% If samples2 is empty, then samples2==samples1 is assumed. 
%
% required fields of params:
%    deg : integer degree of the kernel.
%    b   : the bias within the polynomial kernel.
%
% K(i1,i2) is the inner product (<samples1(:,i1), samples2(:,i2)> + b)^deg 

% Bernard Haasdonk 20.7.2004

% check_required_fields(params,'b');

if ~isempty(samples2)
  K = (samples1' * samples2 +params.b).^params.deg;
else
  K = (samples1' * samples1 +params.b).^params.deg;
end;





