function pred = predict_kernel_PCA(kernel_data,tparams)
%function pred = predict_kernel_PCA(kernel_data,tparams)
%  
% function performing kernel PCA feature extraction on certain
% kernel data. 
%
% required fields of kernel_data:
%    Ktraintest  : kernel matrix of training versus test samples
%    Ktraintrain : square, symmetric kernel matrix of training samples 
%
% required fields of tparams :
%    alphas      : matrix of expansion coefficients (EVD of
%                  centered Ktraintrain obtained from train_kernel_PCA)
%    KPCAind     : number of the KPCA component, on which projection is
%                  to be performed
%
% resulting fields in pred:
%    projections      : resulting kernel PCA values of the test
%                       samples corresponding to the selected KPCA component.

% Bernard Haasdonk 25.7.2005

pred = [];
pred.projections = [];

% given component number i
% f(x) = sum_j alphas(j,i) * <Phi(x)-S,Phi(x_j)-S>
% can be reformulated by centering
if tparams.KPCAind < 1
  disp('KPCA component index not in suitable range, taking as 1!');
  tparams.KPCAind = 1;
end;
n = size(kernel_data.Ktraintrain,1);
if tparams.KPCAind>n
  disp(['KPCA component index not in suitable range, taking as ',...
	num2str(n)]);
  tparams.KPCAind = n;
end;
% center test kernel values
J = eye(n)-1/n*ones(n,n); % centering matrix
KCtest =  J*kernel_data.Ktraintest - ...
	  1/n * J * kernel_data.Ktraintrain * ...
	  ones(n,size(kernel_data.Ktraintest,2)); 
pred.projections = tparams.alphas(:,tparams.KPCAind)' * KCtest;
