function pred = predict_nu_hypersphere(kernel_data,tparams)
%function pred = predict_nu_hypersphere(kernel_data,tparams)
%  
% function performing one class classification by enclosing
% hypersphere on certain kernel data. Hereby typical (+1) versus
% new data (-1) is separated. Ties (decision value 0) are set to 
% label 1.
%
% required fields of kernel_data:
%    Ktraintest    : kernel matrix of training versus test samples
%    Ktesttestdiag : diagonal vector of the test-test matrix
%
% required fields of tparams (obtained from train_two_class_C_SVM):
%    alpha       : vector of solution coefficients 
%    bias        : offset of linear discrimination function
% 
% resulting fields in pred:
%    values      : decision values ("distance" from hypersphere) 
%                  of test-samples
%    labels      : predicted label of test samples

% Bernard Haasdonk 25.7.2005

pred = [];
pred.values = [];
pred.labels = [];
pred.values = -(kernel_data.Ktesttestdiag(:) - ...
		2* kernel_data.Ktraintest'*tparams.alpha + ...
		tparams.alpha'*kernel_data.Ktraintrain*tparams.alpha + ...
		tparams.bias);
pred.labels = sign(pred.values);
fi = find(pred.labels==0);
if ~isempty(fi) % set tie decisions to 1
  pred.labels(fi) = 1;
end;

