function pred = predict_two_class_C_SVM(kernel_data,tparams)
%function pred = predict_two_class_C_SVM(kernel_data,tparams)
% 
% function performing two-class C-SVM prediction on 
% certain kernel data. Ties (decision value 0) are set to label 1.
%
% required fields of kernel_data:
%    Ktraintest  : kernel matrix of training versus test samples
%    labels      : vector of binary labels +1,-1 of the training samples
%
% required fields of tparams (obtained from train_two_class_C_SVM):
%    alpha       : vector of solution coefficients 
%    bias        : offset of linear discrimination function
% 
% resulting fields in pred:
%    values      : decision values ("distance" from hyperplane) 
%                  of test-samples
%    labels      : predicted labels of test samples

% Bernard Haasdonk 25.7.2005

pred = [];
pred.values = [];
pred.labels = [];

pred.values = sum(diag(kernel_data.labels(:).*tparams.alpha)*...
		  kernel_data.Ktraintest,1)+tparams.bias;
pred.labels = sign(pred.values);
fi = find(pred.labels==0);
if ~isempty(fi) % set tie decisions to 1
  pred.labels(fi) = 1;
end;

