function K = pseudo_euclidean_kernel_matrix(samples1,samples2, ...
				  params);
% function K = pseudo_euclidean_kernel_matrix(samples1,samples2,params);
%
% function computing a pseudo-euclidean kernel matrix
% between the (column)-vectors in samples1 and samples2.
% This is the prototype example of an indefinite inner product,
% which nevertheless can be used in some kernel methods.
%
% If samples2 is empty, then samples2==samples1 is assumed. 
%
% required fields of params:
%    b : the bias added to the linear kernel.
%    p : the positive part of the signature (p,q) of the pE space,
%        i.e. the number of leading vector components in the
%        real direction. The remaining components are assumed
%        to correspond to the imaginary directions.
%
% K(i1,i2) is the inner product samples1(:,i1) * M * samples2(:,i2)> + b 
% where M is a diagnal matrix with p entries 1 and n-p entries -1

% Bernard Haasdonk 20.7.2004

% check_required_fields(params,'b');

if params.p>size(samples1,1)
  disp(['error in pE inner product: signature p cannot be larger' ...
	' than vector dimension, taking p=dim (euclidean space).']);
  params.p = size(samples1,1);
end;

M = diag([ones(params.p,1);-ones(size(samples1,1)-params.p,1)]);

if ~isempty(samples2)
  K = samples1' * M * samples2 +params.b;
else
  K = samples1' * M * samples1 +params.b;
end;  






