function tparams = train_kernel_PCA(kernel_data,params)
%function tparams = train_kernel_PCA(kernel_data,params)
% 
% function performing kernel PCA eigendecomposition with certain kernel
% training data. 
%
% required fields of kernel_data:
%    Ktraintrain  : square, symmetric training kernel matrix
%
% required fields of params:
%    none
%
% resulting fields in tparams:
%    alphas        : matrix with expansion coefficients for
%                    eigenvectors of centered kernel matrix.

% Bernard Haasdonk 25.7.2005

tparams.alphas = 0;
n = size(kernel_data.Ktraintrain,1);
J = eye(n)-1/n*ones(n,n); % centering matrix
KC = J*kernel_data.Ktraintrain*J; % centered kernel matrix
KC = 0.5*(KC+KC'); % symmetrize due to small inconsistencies
[v,e] = eig(KC); % eigenvalues/vectors unsorted
evals = diag(e);
[s,si] = sort(-evals);
%  s = -s;
tparams.alphas = v(:,si);

