function tparams = train_kernel_perceptron(kernel_data,params)
%function tparams = train_kernel_perceptron(kernel_data,params)
%
% function performing kernel perceptron training with certain kernel
% training data. 
%
% required fields of kernel_data:
%    Ktraintrain  : square, symmetric training kernel matrix
%    labels       : vector of binary labels +1,-1 of the training samples
%
% required fields of params:
%    max_nupdates : maximum number of updates to be performed   
%
% resulting fields in tparams:
%    alpha        : vector of solution coefficients 
%    bias         : offset of linear discrimination function
%    nupdates     : number of updates performed

% Bernard Haasdonk 25.7.2005

tparams.alpha = 0;
tparams.bias = 0;
tparams.nupdates = 0;

if params.max_nupdates<1
  disp('number of updates not in suitable range, taking as 1!');
  params.max_nupdates = 1;
end;
tparams.nupdates = 0 ; % number of performed updates
tparams.alpha = zeros(size(kernel_data.Ktraintrain,1),1); % current sol-weights
tparams.bias = 0;  % current bias of solution
i = 0;     % index of current investigated training sample
correct_separation = 0;
while (tparams.nupdates < params.max_nupdates) & ~correct_separation
  % determine next error or whether correct separation is
  % available
  no_update = 1;
  last_i = i; % index of last updated sample
  while no_update & ~correct_separation 
    i = mod(i,size(kernel_data.Ktraintrain,1))+1;
    if (kernel_data.Ktraintrain(i,:)*diag(kernel_data.labels)* ...
	tparams.alpha+tparams.bias)*kernel_data.labels(i) <= 0
      tparams.alpha(i) = tparams.alpha(i)+1;
      tparams.bias = tparams.bias + kernel_data.labels(i);
      tparams.nupdates = tparams.nupdates +1;
      no_update = 0;
    end;
    if i==last_i & no_update
      correct_separation = 1;
    end;
  end;
end;

if tparams.nupdates < params.max_nupdates
  disp(['training aborted after ',num2str(tparams.nupdates),...
	' updates with correct separation']);
end;

