function K = tria_DS_kernel_matrix(samples1,samples2,params);
% function K = tria_DS_kernel_matrix(samples1,samples2,params);
%
% function computing triangular distance substitution (DS) kernel matrix 
% between the (column)-vectors in samples1 and samples2.
%
% If samples2 is empty, then samples2==samples1 is assumed. 
%
% required fields of params:
%    beta     : the beta of the triangular-kernel.
%    Dsq_func : name of the squared distance function for computation of
%               distance matrix.
%
% K(i1,i2) is  
%      -Dsq_func(samples1(:,i1),samples2(:,i2))^(beta/2)

% Bernard Haasdonk 22.7.2004

%check_required_fields(params,'beta','Dsq_func');

K = -eval([params.Dsq_func,'(samples1,samples2,params);']).^(params.beta/2);



