function K = tria_kernel_matrix(samples1,samples2,params);
% function K = tria_kernel_matrix(samples1,samples2,params);
%
% function computing the triangular kernel matrix between the
% (column)-vectors in samples1 and samples2. Optionally other
% powers can be defined. 
%
% If samples2 is empty, then samples2==samples1 is assumed. 
% 
% required fields of params:
% beta : power of the triangular kernel (between 0 and 2 results in 
%        conditionally positive definite kernel matrix)
%
% K(i1,i2) is the negative l2-distance powered by beta: 
%     - |samples1(:,i1)- samples2(:,i2)|^beta

% Bernard Haasdonk 20.7.2004

%  check_required_fields(params,'beta');

K = -EDsq_matrix(samples1,samples2).^(params.beta/2);



